RST_R

Type Alias RST_R 

pub type RST_R = BitReader<RST_A>;
Field RST reader - Software Reset.

Aliased Type

pub struct RST_R { /* private fields */ }

Implementations

Source

impl RST_R

pub fn variant(&self) -> RST_A

Get enumerated values variant

pub fn is_rst_0(&self) -> bool

Checks if the value of the field is RST_0

pub fn is_rst_1(&self) -> bool

Checks if the value of the field is RST_1