W

Struct W 

pub struct W(/* private fields */);
Register STAT writer

Implementations

Source

impl W

pub fn mstarbloss(&mut self) -> MSTARBLOSS_W<'_, 4>

Bit 4 - Master Arbitration Loss flag. This flag can be cleared by software writing a 1 to this bit. It is also cleared automatically a 1 is written to MSTCONTINUE.

pub fn mstststperr(&mut self) -> MSTSTSTPERR_W<'_, 6>

Bit 6 - Master Start/Stop Error flag. This flag can be cleared by software writing a 1 to this bit. It is also cleared automatically a 1 is written to MSTCONTINUE.

pub fn slvdesel(&mut self) -> SLVDESEL_W<'_, 15>

Bit 15 - Slave Deselected flag. This flag will cause an interrupt when set if enabled via INTENSET. This flag can be cleared by writing a 1 to this bit.

pub fn monov(&mut self) -> MONOV_W<'_, 17>

Bit 17 - Monitor Overflow flag.

pub fn monidle(&mut self) -> MONIDLE_W<'_, 19>

Bit 19 - Monitor Idle flag. This flag is set when the Monitor function sees the I2C bus change from active to inactive. This can be used by software to decide when to process data accumulated by the Monitor function. This flag will cause an interrupt when set if enabled via the INTENSET register. The flag can be cleared by writing a 1 to this bit.

pub fn eventtimeout(&mut self) -> EVENTTIMEOUT_W<'_, 24>

Bit 24 - Event Time-out Interrupt flag. Indicates when the time between events has been longer than the time specified by the TIMEOUT register. Events include Start, Stop, and clock edges. The flag is cleared by writing a 1 to this bit. No time-out is created when the I2C-bus is idle.

pub fn scltimeout(&mut self) -> SCLTIMEOUT_W<'_, 25>

Bit 25 - SCL Time-out Interrupt flag. Indicates when SCL has remained low longer than the time specific by the TIMEOUT register. The flag is cleared by writing a 1 to this bit.

pub unsafe fn bits(&mut self, bits: u32) -> &mut Self

Writes raw bits to the register.

Methods from Deref<Target = W<STAT_SPEC>>

pub unsafe fn bits(&mut self, bits: REG::Ux) -> &mut Self

Writes raw bits to the register.

Safety

Read datasheet or reference manual to find what values are allowed to pass.