pub struct R(/* private fields */);Expand description
Register CAPTURE_L reader
Implementations
Sourceimpl R
impl R
Sourcepub fn capture_value(&self) -> CAPTURE_VALUE_R
pub fn capture_value(&self) -> CAPTURE_VALUE_R
Bits 0:31 - A read reflects the value of the lower 32 bits of the central 42-bits EVTIMER at the time the last capture signal was generated by the CPU (using CMSIS C function “__SEV();”).
Methods from Deref<Target = R<CAPTURE_L_SPEC>>