SWRESET_W

Type Alias SWRESET_W 

pub type SWRESET_W<'a, const O: u8> = BitWriter<'a, u32, CTRL_SPEC, SWRESET_A, O>;
Field SWRESET writer - Software reset control.

Aliased Type

pub struct SWRESET_W<'a, const O: u8> { /* private fields */ }

Implementations

Source

impl<'a, const O: u8> SWRESET_W<'a, O>

pub fn not_in_reset(self) -> &'a mut W

Not in reset. The RTC is not held in reset. This bit must be cleared prior to configuring or initiating any operation of the RTC.

pub fn in_reset(self) -> &'a mut W

In reset. The RTC is held in reset. All register bits within the RTC will be forced to their reset value except the OFD bit. This bit must be cleared before writing to any register in the RTC - including writes to set any of the other bits within this register. Do not attempt to write to any bits of this register at the same time that the reset bit is being cleared.