#[repr(u8)]pub enum SETCLR3_A {
INDEPENDENT = 0,
L_REVERSED = 1,
H_REVERSED = 2,
}Expand description
Set/clear operation on output 3.
Value on reset: 0
Variants
INDEPENDENT = 0
0: Set and clear do not depend on the direction of any counter.
L_REVERSED = 1
1: Set and clear are reversed when counter L or the unified counter is counting down.
H_REVERSED = 2
2: Set and clear are reversed when counter H is counting down. Do not use if UNIFY = 1.