pub type DATAINSEL_W<'a, const O: u8> = FieldWriter<'a, u32, FCCTRLSEL_SPEC, u8, DATAINSEL_A, 2, O>;Expand description
Field DATAINSEL writer - Selects the source for DATA input to this Flexcomm.
Aliased Type
pub struct DATAINSEL_W<'a, const O: u8> { /* private fields */ }Implementations
Sourceimpl<'a, const O: u8> DATAINSEL_W<'a, O>
impl<'a, const O: u8> DATAINSEL_W<'a, O>
Sourcepub fn orig_flex_i2s_signals(self) -> &'a mut W
pub fn orig_flex_i2s_signals(self) -> &'a mut W
Selects the dedicated FCn_RXD_SDA_MOSI_DATA input for this Flexcomm.
Input data is taken from shared signal set 0 (defined by SHAREDCTRLSET0).
Input data is taken from shared signal set 1 (defined by SHAREDCTRLSET1).