DATAOUTSEL_W

Type Alias DATAOUTSEL_W 

pub type DATAOUTSEL_W<'a, const O: u8> = FieldWriter<'a, u32, FCCTRLSEL_SPEC, u8, DATAOUTSEL_A, 2, O>;
Field DATAOUTSEL writer - Selects the source for DATA output from this Flexcomm.

Aliased Type

pub struct DATAOUTSEL_W<'a, const O: u8> { /* private fields */ }

Implementations

Source

impl<'a, const O: u8> DATAOUTSEL_W<'a, O>

pub fn orig_flex_i2s_signals(self) -> &'a mut W

Selects the dedicated FCn_RXD_SDA_MOSI_DATA output from this Flexcomm.

pub fn shared_set0_i2s_signals(self) -> &'a mut W

Output data is taken from shared signal set 0 (defined by SHAREDCTRLSET0).

pub fn shared_set1_i2s_signals(self) -> &'a mut W

Output data is taken from shared signal set 1 (defined by SHAREDCTRLSET1).