SCKINSEL_R

Type Alias SCKINSEL_R 

pub type SCKINSEL_R = FieldReader<u8, SCKINSEL_A>;
Field SCKINSEL reader - Selects the source for SCK going into this Flexcomm.

Aliased Type

pub struct SCKINSEL_R { /* private fields */ }

Implementations

Source

impl SCKINSEL_R

pub fn variant(&self) -> Option<SCKINSEL_A>

Get enumerated values variant

pub fn is_orig_flex_i2s_signals(&self) -> bool

Checks if the value of the field is ORIG_FLEX_I2S_SIGNALS

pub fn is_shared_set0_i2s_signals(&self) -> bool

Checks if the value of the field is SHARED_SET0_I2S_SIGNALS

pub fn is_shared_set1_i2s_signals(&self) -> bool

Checks if the value of the field is SHARED_SET1_I2S_SIGNALS