WSINSEL_R

Type Alias WSINSEL_R 

pub type WSINSEL_R = FieldReader<u8, WSINSEL_A>;
Field WSINSEL reader - Selects the source for WS going into this Flexcomm.

Aliased Type

pub struct WSINSEL_R { /* private fields */ }

Implementations

Source

impl WSINSEL_R

pub fn variant(&self) -> Option<WSINSEL_A>

Get enumerated values variant

pub fn is_orig_flex_i2s_signals(&self) -> bool

Checks if the value of the field is ORIG_FLEX_I2S_SIGNALS

pub fn is_shared_set0_i2s_signals(&self) -> bool

Checks if the value of the field is SHARED_SET0_I2S_SIGNALS

pub fn is_shared_set1_i2s_signals(&self) -> bool

Checks if the value of the field is SHARED_SET1_I2S_SIGNALS