FC2DATAOUTEN_R

Type Alias FC2DATAOUTEN_R 

pub type FC2DATAOUTEN_R = BitReader<FC2DATAOUTEN_A>;
Field FC2DATAOUTEN reader - Controls FC2 contribution to SHAREDDATAOUT for this shared set.

Aliased Type

pub struct FC2DATAOUTEN_R { /* private fields */ }

Implementations

Source

impl FC2DATAOUTEN_R

pub fn variant(&self) -> FC2DATAOUTEN_A

Get enumerated values variant

pub fn is_input(&self) -> bool

Checks if the value of the field is INPUT

pub fn is_output(&self) -> bool

Checks if the value of the field is OUTPUT