SHAREDDATASEL_R

Type Alias SHAREDDATASEL_R 

pub type SHAREDDATASEL_R = FieldReader<u8, SHAREDDATASEL_A>;
Field SHAREDDATASEL reader - Selects the source for DATA input for this shared signal set.

Aliased Type

pub struct SHAREDDATASEL_R { /* private fields */ }

Implementations

Source

impl SHAREDDATASEL_R

pub fn variant(&self) -> SHAREDDATASEL_A

Get enumerated values variant

pub fn is_flexcomm0(&self) -> bool

Checks if the value of the field is FLEXCOMM0

pub fn is_flexcomm1(&self) -> bool

Checks if the value of the field is FLEXCOMM1

pub fn is_flexcomm2(&self) -> bool

Checks if the value of the field is FLEXCOMM2

pub fn is_flexcomm3(&self) -> bool

Checks if the value of the field is FLEXCOMM3

pub fn is_flexcomm4(&self) -> bool

Checks if the value of the field is FLEXCOMM4

pub fn is_flexcomm5(&self) -> bool

Checks if the value of the field is FLEXCOMM5

pub fn is_flexcomm6(&self) -> bool

Checks if the value of the field is FLEXCOMM6

pub fn is_flexcomm7(&self) -> bool

Checks if the value of the field is FLEXCOMM7