pub type RST_R = BitReader<RST_A>;
Field RST reader - Software Reset.
RST
pub struct RST_R { /* private fields */ }
Get enumerated values variant
Checks if the value of the field is RST_0
RST_0
Checks if the value of the field is RST_1
RST_1