pub type SCKINSEL_R = FieldReader<u8, SCKINSEL_A>;Expand description
Field SCKINSEL reader - Selects the source for SCK going into this Flexcomm.
Aliased Type
pub struct SCKINSEL_R { /* private fields */ }Implementations
Sourceimpl SCKINSEL_R
impl SCKINSEL_R
Sourcepub fn variant(&self) -> Option<SCKINSEL_A>
pub fn variant(&self) -> Option<SCKINSEL_A>
Get enumerated values variant
Sourcepub fn is_orig_flex_i2s_signals(&self) -> bool
pub fn is_orig_flex_i2s_signals(&self) -> bool
Checks if the value of the field is ORIG_FLEX_I2S_SIGNALS
Checks if the value of the field is SHARED_SET0_I2S_SIGNALS
Checks if the value of the field is SHARED_SET1_I2S_SIGNALS